@@ -185,11 +185,11 @@ mime_types:             $mimetypefile
 EOT
 close CONF;
 
-my $ret = system( "$htdigbin/htdig -v -s -i -c $conffile" );
+my $ret = system( "$htdigbin/htdig", "-v", "-s", "-i", "-c", $conffile );
 if ( $ret != 0 ) {
   print STDERR "htdig failed\n";
 } else {
-  $ret = system( "$htdigbin/htmerge -c $conffile" );
+  $ret = system( "$htdigbin/htmerge", "-c", $conffile );
   if ( $ret != 0 ) { print STDERR "htmerge failed\n"; }
 }
 
